Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(614)

Unified Diff: runtime/vm/raw_object.h

Issue 1287463003: Refactor skipped code functions interface. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: rm garbage file. Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/raw_object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/raw_object.h
diff --git a/runtime/vm/raw_object.h b/runtime/vm/raw_object.h
index fe8425911540386ea12e78ffe4233d2b07b323bc..19a1de512c72ebba6ecb0fe39c6add1bd4ca33ff 100644
--- a/runtime/vm/raw_object.h
+++ b/runtime/vm/raw_object.h
@@ -583,6 +583,7 @@ class RawObject {
friend class ScavengerVisitor;
friend class SizeExcludingClassVisitor; // GetClassId
friend class RetainingPathVisitor; // GetClassId
+ friend class SkippedCodeFunctions; // StorePointer
friend class SnapshotReader;
friend class SnapshotWriter;
friend class String;
@@ -743,8 +744,8 @@ class RawFunction : public RawObject {
};
private:
- // So that the MarkingVisitor::DetachCode can null out the code fields.
- friend class MarkingVisitor;
+ // So that the SkippedCodeFunctions::DetachCode can null out the code fields.
+ friend class SkippedCodeFunctions;
friend class Class;
RAW_HEAP_OBJECT_IMPLEMENTATION(Function);
static bool ShouldVisitCode(RawCode* raw_code);
@@ -1026,6 +1027,7 @@ class RawCode : public RawObject {
friend class Function;
friend class MarkingVisitor;
+ friend class SkippedCodeFunctions;
friend class StackFrame;
};
@@ -1077,6 +1079,7 @@ class RawInstructions : public RawObject {
friend class Code;
friend class StackFrame;
friend class MarkingVisitor;
+ friend class SkippedCodeFunctions;
friend class Function;
};
« no previous file with comments | « runtime/vm/object.h ('k') | runtime/vm/raw_object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698